# Code of Conduct

This project follows the Contributor Covenant Code of Conduct.

## Our Pledge
We pledge to make participation in our community a harassment-free experience for everyone.

## Our Standards
Examples of behavior that contributes to a positive environment include:
- Being respectful and considerate
- Giving and gracefully accepting constructive feedback
- Focusing on what is best for the community

Examples of unacceptable behavior include:
- Harassment or discriminatory language
- Personal or political attacks
- Publishing others' private information without permission

## Enforcement
Instances of abusive behavior may be reported to the project team at team@super-agentic.ai.
All complaints will be reviewed and investigated and will result in a response deemed necessary.

## Attribution
This Code of Conduct is adapted from the Contributor Covenant, version 2.1.
